import { Consumer, Producer } from '@cross-lab-project/soa-client';
import { DataChannel } from '@cross-lab-project/soa-client';
import { TypedEmitter } from 'tiny-typed-emitter';
const ServiceType = 'https://api.goldi-labs.de/serviceTypes/message';
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for MessageService type");
    }
}
export class MessageService__Producer {
    constructor(serviceId) {
        this.serviceType = ServiceType;
        this.serviceDirection = Producer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, "data", channel);
        }
        else {
            connection.receive(serviceConfig, "data", channel);
        }
        this.channel = channel;
    }
    async sendMessage(message, messageType) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ messageType: messageType, message: message }));
        }
    }
}
export class MessageService__Consumer extends TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = Consumer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        channel.ondata = this.handleData.bind(this);
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, "data", channel);
        }
        else {
            connection.receive(serviceConfig, "data", channel);
        }
    }
    handleData(data) {
        if (typeof data === 'string') {
            const msg = JSON.parse(data);
            this.emit('message', { message_type: msg.messageType, message: msg.message });
        }
    }
}
//# sourceMappingURL=message_service.js.map